/*
 * FancyBox - jQuery Plugin
 * Simple and fancy lightbox alternative
 * Copyright (c) 2008 - 2010 Janis Skarnelis
 *
 * Version: 1.3.1 (05/03/2010)
 * Requires: jQuery v1.3+
 *
 * Dual licensed under the MIT and GPL licenses:
 *   http://www.opensource.org/licenses/mit-license.php
 *   http://www.gnu.org/licenses/gpl.html
 */

#xhostplusbox-loading {
	position: fixed;
	top: 50%;
	left: 50%;
	height: 40px;
	width: 40px;
	margin-top: -20px;
	margin-left: -20px;
	cursor: pointer;
	overflow: hidden;
	z-index: 1104;
	display: none;
}

* html #xhostplusbox-loading {	/* IE6 */
	position: absolute;
	margin-top: 0;
}

#xhostplusbox-loading div {
	position: absolute;
	top: 0;
	left: 0;
	width: 40px;
	height: 480px;
}

#xhostplusbox-overlay {
	position: fixed;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	background: #000;
	z-index: 1100;
	display: none;
}

* html #xhostplusbox-overlay {	/* IE6 */
	position: absolute;
	width: 100%;
}

#xhostplusbox-tmp {
	padding: 0;
	margin: 0;
	border: 0;
	overflow: auto;
	display: none;
}

#xhostplusbox-wrap {
	position: absolute;
	top: 0;
	left: 0;
	margin: 0;
	padding: 20px;
	z-index: 1101;
	display: none;
}

#xhostplusbox-outer {
	position: relative;
	width: 100%;
	height: 100%;
	background: #FFF;
}

#xhostplusbox-inner {
	position: absolute;
	top: 0;
	left: 0;
	width: 1px;
	height: 1px;
	padding: 0;
	margin: 0;
	outline: none;
	overflow: hidden;
}

#xhostplusbox-hide-sel-frame {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background: transparent;
}

#xhostplusbox-close {
	position: absolute;
	top: -15px;
	right: -15px;
	width: 30px;
	height: 30px;
	background-position: -40px 0px;
	cursor: pointer;
	z-index: 1103;
	display: none;
}

#xhostplusbox_error {
	color: #444;
	font: normal 12px/20px Arial;
	padding: 7px;
	margin: 0;
}

#xhostplusbox-content {
	height: auto;
	width: auto;
	padding: 0;
	margin: 0;
}

#xhostplusbox-img {
	width: 100%;
	height: 100%;
	padding: 0;
	margin: 0;
	border: none;
	outline: none;
	line-height: 0;
	vertical-align: top;
	-ms-interpolation-mode: bicubic;
}

#xhostplusbox-frame {
	position: relative;
	width: 100%;
	height: 100%;
	border: none;
	display: block;
}

#xhostplusbox-title {
	position: absolute;
	bottom: 0;
	left: 0;
	font-family: Arial;
	font-size: 12px;
	z-index: 1102;
}

.xhostplusbox-title-inside {
	padding: 10px 0;
	text-align: center;
	color: #333;
}

.xhostplusbox-title-outside {
	padding-top: 5px;
	color: #FFF;
	text-align: center;
	font-weight: bold;
}

.xhostplusbox-title-over {
	color: #FFF;
	text-align: left;
}

#xhostplusbox-title-over {
	padding: 10px;
	display: block;
}

#xhostplusbox-title-wrap {
	display: inline-block;
}

#xhostplusbox-title-wrap span {
	height: 32px;
	float: left;
}

#xhostplusbox-title-left {
	padding-left: 15px;
	background-position: -40px -90px;
	background-repeat: no-repeat;
}

#xhostplusbox-title-main {
	font-weight: bold;
	line-height: 29px;
	background-position: 0px -40px;
	color: #FFF;
}

#xhostplusbox-title-right {
	padding-left: 15px;
	background-position: -55px -90px;
	background-repeat: no-repeat;
}

#xhostplusbox-left, #xhostplusbox-right {
	position: absolute;
	bottom: 0px;
	height: 100%;
	width: 35%;
	cursor: pointer;
	outline: none;
	z-index: 1102;
	display: none;
}

#xhostplusbox-left {
	left: 0px;
}

#xhostplusbox-right {
	right: 0px;
}

#xhostplusbox-left-ico, #xhostplusbox-right-ico {
	position: absolute;
	top: 50%;
	left: -9999px;
	width: 30px;
	height: 30px;
	margin-top: -15px;
	cursor: pointer;
	z-index: 1102;
	display: block;
}

#xhostplusbox-left-ico {
	background-position: -40px -30px;
}

#xhostplusbox-right-ico {
	background-position: -40px -60px;
}

#xhostplusbox-left:hover, #xhostplusbox-right:hover {
	visibility: visible;    /* IE6 */
}

#xhostplusbox-left:hover span {
	left: 20px;
}

#xhostplusbox-right:hover span {
	left: auto;
	right: 20px;
}

.fancy-bg {
	position: absolute;
	padding: 0;
	margin: 0;
	border: 0;
	width: 20px;
	height: 20px;
	z-index: 1001;
}

#fancy-bg-n {
	top: -20px;
	left: 0;
	width: 100%;
}

#fancy-bg-ne {
	top: -20px;
	right: -20px;
	background-position: -40px -162px;
}

#fancy-bg-e {
	top: 0;
	right: -20px;
	height: 100%;
	background-position: -20px 0px;
}

#fancy-bg-se {
	bottom: -20px;
	right: -20px;
	background-position: -40px -182px; 
}

#fancy-bg-s {
	bottom: -20px;
	left: 0;
	width: 100%;
	background-position: 0px -20px;
}

#fancy-bg-sw {
	bottom: -20px;
	left: -20px;
	background-position: -40px -142px;
}

#fancy-bg-w {
	top: 0;
	left: -20px;
	height: 100%;
}

#fancy-bg-nw {
	top: -20px;
	left: -20px;
	background-position: -40px -122px;
}